@@ -3,6 +3,12 @@
 #' @family Literate programming targets
 #' @description Shorthand to include `knitr` document in a
 #'   `targets` pipeline.
+#'
+#'   [tar_knit()] expects an unevaluated symbol for the `name` argument,
+#'   and it supports named `...` arguments for `knitr::knit()` arguments.
+#'   [tar_knit_raw()] expects a character string for `name` and
+#'   supports an evaluated expression object
+#'   `knit_arguments` for `knitr::knit()` arguments.
 #' @details `tar_knit()` is an alternative to `tar_target()` for
 #'   `knitr` reports that depend on other targets. The `knitr` source
 #'   should mention dependency targets with `tar_load()` and `tar_read()`
@@ -36,15 +42,30 @@
 #' @inheritSection tar_map Target objects
 #' @inheritParams targets::tar_target
 #' @inheritParams knitr::knit
+#' @inheritParams tar_render
+#' @param name Name of the target.
+#'   [tar_knit()] expects an unevaluated symbol for the `name` argument,
+#'   whereas [tar_knit_raw()] expects a character string for `name`.
 #' @param path Character string, file path to the `knitr` source file.
 #'   Must have length 1.
 #' @param ... Named arguments to `knitr::knit()`.
-#'   These arguments are evaluated when the target actually runs in
+#'   These arguments are unevaluated when supplied to [tar_knit()].
+#'   They are only evaluated when the target actually runs in
 #'   `tar_make()`, not when the target is defined.
+#' @param knit_arguments Optional language object with a list
+#'   of named arguments to `knitr::knit()`.
+#'   Cannot be an expression object.
+#'   (Use `quote()`, not `expression()`.)
+#'   The reason for quoting is that these arguments may depend on
+#'   upstream targets whose values are not available at
+#'   the time the target is defined, and because `tar_knit_raw()`
+#'   is the "raw" version of a function, we want to avoid
+#'   all non-standard evaluation.
 #' @examples
 #' if (identical(Sys.getenv("TAR_LONG_EXAMPLES"), "true")) {
 #' targets::tar_dir({ # tar_dir() runs code from a temporary directory.
 #' targets::tar_script({
+#'   library(tarchetypes)
 #'   # Ordinarily, you should create the report outside
 #'   # tar_script() and avoid temporary files.
 #'   lines <- c(
@@ -60,8 +81,9 @@
 #'   path <- tempfile()
 #'   writeLines(lines, path)
 #'   list(
-#'     targets::tar_target(data, data.frame(x = seq_len(26), y = letters)),
-#'     tarchetypes::tar_knit(report, path)
+#'     tar_target(data, data.frame(x = seq_len(26), y = letters)),
+#'     tar_knit(name = report, path = path),
+#'     tar_knit_raw(name = "report2", path = path)
 #'   )
 #' })
 #' targets::tar_make()
@@ -70,6 +92,8 @@
 tar_knit <- function(
   name,
   path,
+  output_file = NULL,
+  working_directory = NULL,
   tidy_eval = targets::tar_option_get("tidy_eval"),
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
@@ -81,13 +105,17 @@ tar_knit <- function(
   resources = targets::tar_option_get("resources"),
   retrieval = targets::tar_option_get("retrieval"),
   cue = targets::tar_option_get("cue"),
+  description = targets::tar_option_get("description"),
   quiet = TRUE,
   ...
 ) {
   targets::tar_assert_package("knitr")
-  targets::tar_assert_scalar(path)
-  targets::tar_assert_chr(path)
-  targets::tar_assert_path(path)
+  targets::tar_assert_file(path)
+  targets::tar_assert_chr(output_file %|||% "x")
+  targets::tar_assert_scalar(output_file %|||% "x")
+  if (!is.null(working_directory)) {
+    targets::tar_assert_file(working_directory)
+  }
   envir <- tar_option_get("envir")
   args <- targets::tar_tidy_eval(
     substitute(list(...)),
@@ -96,7 +124,13 @@ tar_knit <- function(
   )
   targets::tar_target_raw(
     name = targets::tar_deparse_language(substitute(name)),
-    command = tar_knit_command(path, args, quiet),
+    command = tar_knit_command(
+      path,
+      output_file,
+      working_directory,
+      args,
+      quiet
+    ),
     packages = packages,
     library = library,
     format = "file",
@@ -108,16 +142,30 @@ tar_knit <- function(
     priority = priority,
     resources = resources,
     retrieval = retrieval,
-    cue = cue
+    cue = cue,
+    description = description
   )
 }
 
-tar_knit_command <- function(path, args, quiet) {
+tar_knit_command <- function(
+  path,
+  output_file,
+  working_directory,
+  args,
+  quiet
+) {
   args$input <- path
+  args$output <- output_file
   args$quiet <- quiet
   deps <- call_list(as_symbols(knitr_deps(path)))
   fun <- call_ns("tarchetypes", "tar_knit_run")
-  exprs <- list(fun, path = path, args = args, deps = deps)
+  exprs <- list(
+    fun,
+    path = path,
+    working_directory = working_directory,
+    args = args,
+    deps = deps
+  )
   as.expression(as.call(exprs))
 }
 
@@ -130,15 +178,15 @@ tar_knit_command <- function(path, args, quiet) {
 #'   and the relative path to the output `knitr` report.
 #'   The output path depends on the input path argument,
 #'   which has no default.
-#' @param path Path to the `knitr` source file.
+#' @inheritParams tar_knit
 #' @param args A named list of arguments to `knitr::knit()`.
 #' @param deps An unnamed list of target dependencies of the `knitr`
 #'   report, automatically created by `tar_knit()`.
-tar_knit_run <- function(path, args, deps) {
+tar_knit_run <- function(path, working_directory, args, deps) {
   targets::tar_assert_package("knitr")
   withr::local_options(list(crayon.enabled = NULL))
   opt <- knitr::opts_knit$get("root.dir")
-  knitr::opts_knit$set(root.dir = getwd())
+  knitr::opts_knit$set(root.dir = working_directory %|||% getwd())
   on.exit(knitr::opts_knit$set(root.dir = opt))
   envir <- parent.frame()
   args$envir <- args$envir %|||% targets::tar_envir(default = envir)
