@@ -6,7 +6,9 @@ targets::tar_test("tar_cue_force(FALSE)", {
   expect_equal(targets::tar_read(x), 0L)
   for (i in seq_len(2)) {
     targets::tar_make(callr_function = NULL)
-    expect_equal(nrow(targets::tar_progress()), 0L)
+    progress <- targets::tar_progress()
+    progress <- progress[progress$progress != "skipped", ]
+    expect_equal(nrow(progress), 0L)
   }
 })
 
@@ -18,6 +20,8 @@ targets::tar_test("tar_cue_force(TRUE)", {
   expect_equal(targets::tar_read(x), 0L)
   for (i in seq_len(2)) {
     targets::tar_make(callr_function = NULL)
-    expect_equal(targets::tar_progress()$name, "x")
+    progress <- targets::tar_progress()
+    progress <- progress[progress$progress != "skipped", ]
+    expect_equal(progress$name, "x")
   }
 })
