@@ -36,8 +36,13 @@ targets::tar_test("tar_map2_size()", {
       paste0(
         "x",
         c(
-          "_i_a", "_i_b", "_ii_a", "_ii_a_combine",
-          "_ii_b", "_ii_b_combine", ""
+          "_i_a",
+          "_i_b",
+          "_ii_a",
+          "_ii_a_combine",
+          "_ii_b",
+          "_ii_b_combine",
+          ""
         )
       )
     )
@@ -62,17 +67,28 @@ targets::tar_test("tar_map2_size()", {
   out <- targets::tar_network(callr_function = NULL)$edges
   out <- dplyr::arrange(out, from, to)
   exp <- tibble::tribble(
-    ~from, ~to,
-    "f1", "x_i_a",
-    "f1", "x_i_b",
-    "f2", "x_ii_a",
-    "f2", "x_ii_b",
-    "x_i_a", "x_ii_a",
-    "x_i_b", "x_ii_b",
-    "x_ii_a", "x_ii_a_combine",
-    "x_ii_b", "x_ii_b_combine",
-    "x_ii_a_combine", "x",
-    "x_ii_b_combine", "x"
+    ~from,
+    ~to,
+    "f1",
+    "x_i_a",
+    "f1",
+    "x_i_b",
+    "f2",
+    "x_ii_a",
+    "f2",
+    "x_ii_b",
+    "x_i_a",
+    "x_ii_a",
+    "x_i_b",
+    "x_ii_b",
+    "x_ii_a",
+    "x_ii_a_combine",
+    "x_ii_b",
+    "x_ii_b_combine",
+    "x_ii_a_combine",
+    "x",
+    "x_ii_b_combine",
+    "x"
   )
   exp <- dplyr::arrange(exp, from, to)
   expect_equal(out, exp)
@@ -93,8 +109,18 @@ targets::tar_test("tar_map2_size()", {
   expect_equal(
     x$result,
     c(
-      "a 1", "a 2", "a 3", "a 4", "a 5", "a 6",
-      "b 1", "b 2", "b 3", "b 4", "b 5", "b 6"
+      "a 1",
+      "a 2",
+      "a 3",
+      "a 4",
+      "a 5",
+      "a 6",
+      "b 1",
+      "b 2",
+      "b 3",
+      "b 4",
+      "b 5",
+      "b 6"
     )
   )
   expect_equal(x$length_arg1, rep(1L, 12L))
