@@ -289,7 +289,7 @@ targets::tar_test("tar_quarto() works with child documents", {
   # Check that the dependency graph is correct of our targets. `report` should
   # depend on `main` and `child`.
   edges <- tar_network(callr_function = NULL)$edges
-  edges <- edges[edges$to == "report",, drop = FALSE] # nolint
+  edges <- edges[edges$to == "report", , drop = FALSE] # nolint
   expect_identical(
     edges,
     tibble::tibble(
@@ -333,14 +333,17 @@ targets::tar_test("quarto projects", {
     "```"
   )
   writeLines(lines, "r2.qmd")
-  targets::tar_script({
-    library(tarchetypes)
-    list(
-      tar_target(r1, "r1_value"),
-      tar_target(r2, "r2_value"),
-      tar_quarto(project)
-    )
-  }, ask = FALSE)
+  targets::tar_script(
+    {
+      library(tarchetypes)
+      list(
+        tar_target(r1, "r1_value"),
+        tar_target(r2, "r2_value"),
+        tar_quarto(project)
+      )
+    },
+    ask = FALSE
+  )
   edges <- targets::tar_network(callr_function = NULL)$edges
   expect_equal(sort(edges$from), sort(c("r1", "r2")))
   expect_equal(edges$to, c("project", "project"))
@@ -354,14 +357,17 @@ targets::tar_test("quarto projects", {
   expect_equal(targets::tar_outdated(callr_function = NULL), "project")
   targets::tar_make(callr_function = NULL)
   expect_equal(targets::tar_outdated(callr_function = NULL), character(0))
-  targets::tar_script({
-    library(tarchetypes)
-    list(
-      tar_target(r1, "r1_value"),
-      tar_target(r2, "r2_value2"),
-      tar_quarto(project)
-    )
-  }, ask = FALSE)
+  targets::tar_script(
+    {
+      library(tarchetypes)
+      list(
+        tar_target(r1, "r1_value"),
+        tar_target(r2, "r2_value2"),
+        tar_quarto(project)
+      )
+    },
+    ask = FALSE
+  )
   expect_equal(
     sort(targets::tar_outdated(callr_function = NULL)),
     sort(c("project", "r2"))
@@ -382,12 +388,7 @@ targets::tar_test("quarto profiles", {
     "testing.qmd"
   )
   writeLines(
-    c("project:",
-      "  output-dir: _output",
-      "",
-      "profile:",
-      "  default: basic"
-    ),
+    c("project:", "  output-dir: _output", "", "profile:", "  default: basic"),
     "_quarto.yml"
   )
   writeLines(
@@ -451,3 +452,160 @@ targets::tar_test("tar_quarto() deprecate packages", {
     class = "tar_condition_deprecate"
   )
 })
+
+targets::tar_test("tar_quarto() creates custom output file", {
+  skip_quarto()
+  lines <- c(
+    "---",
+    "title: report",
+    "output_format: html",
+    "---",
+    "",
+    "```{r}",
+    "targets::tar_read(data)",
+    "```"
+  )
+  writeLines(lines, "report.qmd")
+  targets::tar_script({
+    library(tarchetypes)
+    list(
+      tar_target(data, data.frame(x = seq_len(26L), y = letters)),
+      tar_quarto(report, path = "report.qmd", output_file = "test.html")
+    )
+  })
+  suppressMessages(targets::tar_make(callr_function = NULL))
+  progress <- targets::tar_progress()
+  progress <- progress[progress$progress != "skipped", ]
+  expect_equal(sort(progress$name), sort(c("data", "report")))
+  out <- targets::tar_read(report)
+  out <- setdiff(out, "report_files")
+  expect_equal(sort(basename(out)), sort(c("test.html", "report.qmd")))
+  expect_false(file.exists(file.path("report.html")))
+  expect_true(file.exists(file.path("test.html")))
+})
+
+targets::tar_test("tar_quarto() reruns if target changes in included file", {
+  skip_quarto()
+  lines <- c(
+    "---",
+    "title: main",
+    "output_format: html",
+    "---",
+    "",
+    "{{< include \"file1.qmd\" >}}"
+  )
+  writeLines(lines, "main.qmd")
+  lines <- c(
+    "# First File",
+    "",
+    "Contains a code cell with a target.",
+    "",
+    "```{r}",
+    "targets::tar_read(data)",
+    "```"
+  )
+  writeLines(lines, "file1.qmd")
+  targets::tar_script({
+    library(tarchetypes)
+    list(
+      tar_target(data, data.frame(x = seq_len(26L), y = letters)),
+      tar_quarto(report, path = "main.qmd")
+    )
+  })
+  # First run.
+  suppressMessages(targets::tar_make(callr_function = NULL))
+  progress <- targets::tar_progress()
+  progress <- progress[progress$progress != "skipped", ]
+  expect_equal(sort(progress$name), sort(c("data", "report")))
+  out <- targets::tar_read(report)
+  out <- setdiff(out, "main_files")
+  if (identical(tolower(Sys.info()[["sysname"]]), "windows")) {
+    expect_equal(
+      # On the windows CI, there seems to be issues and `fs::path_rel`. Because
+      # of that, `file1.qmd` is returned twice and we use `unique` here. On
+      # other platforms this issue does not exist.
+      #
+      # See https://github.com/ropensci/tarchetypes/pull/200 for a discussion.
+      sort(unique(basename(out))),
+      sort(c("main.html", "main.qmd", "file1.qmd"))
+    )
+  } else {
+    expect_equal(
+      sort(basename(out)),
+      sort(c("main.html", "main.qmd", "file1.qmd"))
+    )
+  }
+  # Should not rerun the report.
+  suppressMessages(targets::tar_make(callr_function = NULL))
+  progress <- targets::tar_progress()
+  progress <- progress[progress$progress != "skipped", ]
+  expect_equal(nrow(progress), 0L)
+  # Should rerun the report.
+  targets::tar_script({
+    library(tarchetypes)
+    list(
+      tar_target(data, data.frame(x = rev(seq_len(26L)), y = letters)),
+      tar_quarto(report, path = "main.qmd")
+    )
+  })
+  suppressMessages(targets::tar_make(callr_function = NULL))
+  expect_equal(sort(targets::tar_progress()$name), sort(c("data", "report")))
+})
+
+targets::tar_test("tar_quarto() reruns if an included file changes", {
+  skip_quarto()
+  lines <- c(
+    "---",
+    "title: main",
+    "output_format: html",
+    "---",
+    "",
+    "{{< include \"file1.qmd\" >}}"
+  )
+  writeLines(lines, "main.qmd")
+  lines <- c(
+    "# First File",
+    "",
+    "Includes another file.",
+    "",
+    "{{< include \"file2.qmd\" >}}"
+  )
+  writeLines(lines, "file1.qmd")
+  lines <- c(
+    "# Second File",
+    "",
+    "Does not include another file."
+  )
+  writeLines(lines, "file2.qmd")
+  targets::tar_script({
+    library(tarchetypes)
+    list(
+      tar_quarto(report, path = "main.qmd")
+    )
+  })
+  # First run.
+  suppressMessages(targets::tar_make(callr_function = NULL))
+  progress <- targets::tar_progress()
+  progress <- progress[progress$progress != "skipped", ]
+  expect_equal(sort(progress$name), sort(c("report")))
+  out <- targets::tar_read(report)
+  out <- setdiff(out, "main_files")
+  expect_equal(
+    sort(basename(out)),
+    sort(c("main.html", "main.qmd", "file1.qmd", "file2.qmd"))
+  )
+  # Should not rerun the report.
+  suppressMessages(targets::tar_make(callr_function = NULL))
+  progress <- targets::tar_progress()
+  progress <- progress[progress$progress != "skipped", ]
+  expect_equal(nrow(progress), 0L)
+  # Should rerun the report.
+  lines <- c(
+    "# Second File",
+    "",
+    "A change to the second file."
+  )
+  writeLines(lines, "file2.qmd")
+  suppressMessages(targets::tar_make(callr_function = NULL))
+  expect_equal(sort(targets::tar_progress()$name), sort(c("report")))
+})
